import { getOwner } from "@ember/application";
import Component from "@ember/component";
import { task, timeout } from "ember-concurrency";

import layout from "../templates/components/cf-field";

/**
 * Component to display a label and input for a certain field of a document.
 *
 * ```hbs
 * {{cf-field field=someField}}
 * ```
 *
 * You can disable the field by passing `disabled=true`.
 *
 * @class CfFieldComponent
 * @argument {Field} field The field data model to render
 */
export default Component.extend({
  layout,
  classNames: ["uk-margin"],
  classNameBindings: ["field.hidden:uk-hidden"],

  /**
   * Task to save a field. This will set the passed value to the answer and
   * save the field to the API after a timeout off 500 milliseconds.
   *
   * @method save
   * @param {String|Number|String[]} value
   */
  save: task(function* (value) {
    const { environment } = getOwner(this).resolveRegistration(
      "config:environment"
    );

    /* istanbul ignore next */
    if (environment !== "test") {
      yield timeout(500);
    }

    this.set("field.answer.value", value);

    yield this.field.validate.perform();

    try {
      return yield this.field.save.unlinked().perform();
    } catch (e) {
      // that's ok
    }
  }).restartable(),
});
